@@ -1,10 +1,16 @@
 c         this list block data names as external names so that the
 c       block data is surely enabled.
+#ifdef  ZCONDC
+#else
+#include  "Zcondc.h"
+#endif
       external cblkElemag
       external cblkdedx
       external cblkHeavy 
       external cblkManager 
-c      external cblkStdAtmos
+#if  ATMOSPHERE == 0 
+      external cblkStdAtmos
+#endif
       external cblkXsec
       external cblkEvhnp
       external cblkIncident
@@ -17,3 +23,4 @@ c              For Lund related block common
       external ludataC
       external luedatC
       external luhdatC
+
