@@ -28,6 +28,7 @@
       
 c    &&&&&&&&&&&&&&
 c
+
       integer irsave(2)
 c
       real*8    ELAB
@@ -54,6 +55,10 @@ c
       logical dodpm, first
       save first
       data first /.true./
+c////////////
+c      logical deb
+c      common /cdebug/ deb
+c////////////
 
       if(first) then
          NEVENT = 0
@@ -72,6 +77,9 @@ c     *   1, 1, ia, iz,  1, ELAB, KKMAT, icon)
       NTMASS = ia            
       NTCHAR = iz
       ELAB = pj.fm.p(4)
+      if(pj.code .eq. kgnuc) then
+         ELAB = ELAB/pj.subcode
+      endif
       call ccos2dpjidp( pj, IDP, NPMASS, NPCHAR )
 
       dodpm = .false.
@@ -110,46 +118,57 @@ c
                   dodpm  = pj.fm.p(4) .gt. 1.5
                endif
             else
-              dodpm = ( pj.fm.p(4) -pj.mass )/pj.subcode .gt. 1.5
+c                 dpmjet cannot treat heavy int. below 5 GeV
+              dodpm = ELAB .gt. 5.1
            endif
          endif
-      endif
-      if(dodpm) then
-         icon = 1
-         loopc = 0 
-
-         if(pj.code .eq. kgnuc) then
-            ELAB = ELAB/pj.subcode
-         endif
+c           endif here       is moved to the last
+         if(dodpm) then
+            icon = 1
+            loopc = 0 
 
 c                 dpm; GeV/n
-         do while (icon .ne. 0)
+            do while (icon .ne. 0)
 c&&&&&
 c            call rnd1s(irsave)
 c &&&&&
-            call DT_KKINC(
-     *      NPMASS,NPCHAR,NTMASS,NTCHAR,IDP,ELAB,KKMAT,icon)
-            if(icon .ne. 0) then
-               loopc = loopc + 1
-               if(loopc .gt. 100) then
-                  write(ErrorOut,*)
-     *              ' proj code, subcode, charge=',pj.code,
-     *              pj.subcode, pj.charge, ' E=',pj.fm.p(4),
-     *              ' Target A=', ia, ' Z=', iz
-                  call cerrorMsg(
-     *           'dpmjet3 loop>100; ptcl generatation failed',0)     
+               call DT_KKINC(
+     *              NPMASS,NPCHAR,NTMASS,NTCHAR,IDP,ELAB,KKMAT,icon)
+               if(icon .ne. 0) then
+c                   once the event is rejected, even if different
+c                   random number cannot get rid of this loop. 
+c                   so we change the energy by 1 %
+                  ELAB=ELAB*1.01   
+                  loopc = loopc + 1
+c                  if(loopc .gt. 100) then    ! probably useless.
+                  if(loopc .gt.  3) then
+                     write(ErrorOut,*)
+     *                    ' proj code, subcode, charge=',pj.code,
+     *                    pj.subcode, pj.charge, ' E=',pj.fm.p(4),
+     *                    ' Target A=', ia, ' Z=', iz
+                     call cerrorMsg(
+     *              'dpmjet3 loop>100; ptcl generatation failed',0)     
+                  endif
                endif
+            enddo
+            call csetdpmresul(pj, a, ntp)
+         else
+            if(pj.code .le. knuc) then
+c               use fritiof 1.6 or nucrin
+               ActiveMdl = 'byenergy'
+               call chALund(pj, ia, iz, a, ntp)
+            elseif(pj.code .eq. kgnuc) then
+c  
+               call cerrorMsg('Recursive call of heavy routine',0)
+c                    dpmjet is bypaseed for heavy < 5GeV
+c               if(ELAB .gt. 0.5) then
+c                  ActiveMdl = 'byenergy'
+c                  call cheavyInt(pj, ia, iz, a, ntp)
+c               else
+c                  a(1) = pj
+c                  ntp = 1
+c               endif
             endif
-         enddo
-         call csetdpmresul(pj, a, ntp)
-      else
-         if(pj.code .le. knuc) then
-c             use fritiof 1.6 or nucrin
-            ActiveMdl = 'byenergy'
-            call chALund(pj, ia, iz, a, ntp)
-         elseif(pj.code .eq. kgnuc) then
-            a(1) = pj
-            ntp = 1
          endif
       endif
       end
