@@ -6,6 +6,10 @@ c
 #include "Zkfcode.h"
 #include "Zmanagerp.h"
 #include "Zevhnp.h"
+c &&&&&&&&&&
+#include "Zcode.h"
+#include "Zmass.h"
+c  &&&&&&&&&&
 
 c     *******************
       include "Zlujets.h"
@@ -33,7 +37,7 @@ c
 
       integer mstp, msti
       real*8 parp, pari
-      common/pypars/mstp(200),parp(200),msti(200),pari(200)
+      common/pyparsC/mstp(200),parp(200),msti(200),pari(200)
 c                   
       integer ksz1
       parameter (ksz1=20)
@@ -55,6 +59,9 @@ c
       save /ludat1/,/lujets/,/ludat3/
 
       integer lucomp, ind
+c////////////
+c      integer seed(2)
+c////////////
 
       if(first) then
 c           lujets size
@@ -97,7 +104,8 @@ c          set projectile and target info.
          if(kf .eq. kfk0l .or. kf .eq. kfk0s) then
             exma(1,1) = exma(5,1)
             exma(1,2) = exma(5,2)
-         elseif(kf .eq. kfnbar) then
+c         elseif(kf .eq. kfnbar) then
+         elseif(kf .eq. -kfneutron) then
             exma(1,1) = exma(9,1)
             exma(1,2) = exma(9,2)
          elseif(kf .eq. kfpi0) then
@@ -132,6 +140,14 @@ c
 c    ---------------
       n = 2
       do while( n .eq. 2)       ! avoid elestic events
+c//////////////////
+c         if(roots .gt. 1.5e2) then
+c            write(*,*) ' ====== roots=',roots,
+c     *            pjid, tgtid
+c            call rnd1s(seed)
+c            write(*,*) ' seed=', seed
+c         endif   
+c////////////////
          call frevent('cms', pjid, tgtid, roots)
       enddo
 
@@ -146,6 +162,25 @@ c       data in /lujets/ is moved to 'a' with Cosmos code
             a(ntp).fm.p(2) = p(i, 2)
             a(ntp).fm.p(3) = p(i, 3)
             a(ntp).fm.p(4) = p(i, 4)
+         else
+c   &&&&&&&&&&&&&&&&&&&&
+            ntp = ntp + 1
+            code = kgnuc
+            subcode = p(i,5)/masp +  0.5
+            chg = abs( k(i,2) ) - 10000
+c            &&&&&&&&&&&&&& 
+            if(subcode .eq. 0) then
+c              sometimes Fritiof forgets to set mass.
+c              assume it is 2.2*charge
+               subcode = chg*2.2
+            endif
+            call cmkptc(code, subcode, chg, a(ntp))
+            a(ntp).fm.p(1) = p(i, 1)
+            a(ntp).fm.p(2) = p(i, 2)
+            a(ntp).fm.p(3) = p(i, 3)
+            a(ntp).fm.p(4) = p(i, 4)
+            a(ntp).mass = p(i, 5)
+c &&&&&&&&&&&&&&&&&&
          endif
       enddo
       end
@@ -162,19 +197,19 @@ c       For heavy partilce, 0 is returned. (only other hadrons are
 c       treated as projectile in Cosmos.  heavy particle is
 c       not directly treated by Lund.
 
-      if(kf .eq. kfpip) then
+      if(kf .eq. kfpion) then
          ind = 3
-      elseif(kf .eq. kfpim) then
+      elseif(kf .eq. -kfpion) then
          ind = 4
-      elseif(kf .eq. kfkp) then
+      elseif(kf .eq. kfkaon) then
          ind = 5
-      elseif(kf .eq. kfkm) then
+      elseif(kf .eq. -kfkaon) then
          ind = 6
       elseif(kf .eq. kfneutron) then
          ind = 7
       elseif(kf .eq. kfproton) then
          ind = 8
-      elseif(kf .eq. kfpbar) then
+      elseif(kf .eq. -kfproton) then
          ind = 9
       else
          ind = 0
@@ -290,5 +325,3 @@ c
 
       crmsnc= rms(z)
       end
-      
-
