@@ -1,10 +1,10 @@
 
       common /ZdedxAir/ stha, sthb, sthc, sthx0, sthx1, sthsa,
-     *   wlg0, w0,
+     *   wlg0, w0, betasq, tmax, norm,
      *   Knckon, jdef
 
 	real*8  stha, sthb, sthc, sthx0, sthx1, sthsa
-	real*8  wlg0, w0
+	real*8  wlg0, w0, betasq, tmax, norm
 	integer jdef
         logical Knckon
 
