@@ -19,19 +19,34 @@ c
       save  neverNEP, neverE, neverG
       integer never
       save never
+c/////////////
+c      logical deb
+c      common /cccdeb/ deb
+c//////////
 
       record /ptcl/ fragA(maxHeavyMassN),  nonIntNucA(maxHeavyMassN)
       integer noOfFrag, noOfNonIntN
 c
-      record /track/aTrack
+c      record /track/aTrack
 c
 c   **  ptcl stacking is done in each subroutine; should be changed
 c           (except for hadronic interactions)
 
       Nproduced = 0
 
-      aTrack = MovedTrack   !  save incident
+c//////////////
+c         if( deb ) then
+c            write(*,*) ' top of  cinteraction '
+c         endif
+c////////////////
+c
 
+c
+cc    assume MovedTrack is not changed in interaction routine
+c     but may be added asflag by chookEing if it is elec.
+c      (in the case of Job ='newskel' )
+c     
+c
       if(MovedTrack.p.code .eq. kelec) then
          call cinteElec
          if(neverE .ne. 1) then
@@ -49,12 +64,24 @@ c           (except for hadronic interactions)
 
       else
           call cinteNEP
+c//////////////
+c         if( deb ) then
+c            write(*,*) ' aftere cinteNEP '
+c         endif
+c////////////////
+
           if(IntInfArray(ProcessNo).process .eq. 'coll') then
              MovedTrack.pos.colheight = MovedTrack.pos.height
           endif
 c             interface with user hook  ***********************
           if(neverNEP .ne. 1) then
              call chookNEPInt(neverNEP)
+c//////////////
+c         if( deb ) then
+c            write(*,*) ' after chookNEPint '
+c         endif
+c////////////////
+
              never = neverNEP
           endif
 c             *******************************
@@ -63,10 +90,10 @@ c             *******************************
          if(OneDim .eq. 0) then
 c            3 dimensional
 c                 stack the leading ptcl  first (to save stack area)
-            call cmovePtcl3(aTrack, Pwork, Nproduced)
+            call cmovePtcl3(MovedTrack, Pwork, Nproduced)
          else
-            aTrack.vec = IncidentCopy.vec
-            call cmovePtcl1(aTrack, Pwork, Nproduced)
+            MovedTrack.vec = IncidentCopy.vec
+            call cmovePtcl1(MovedTrack, Pwork, Nproduced)
          endif
       elseif(never .eq. 2) then
 c              save only fragments and non interacting nucleons
@@ -78,12 +105,12 @@ c               get fragment and non interacting nuc.
             call cqHvyIntNIN(nonIntNucA, noOfNonIntN)
 
             if(OneDim .eq. 0) then
-                call cmovePtcl3(aTrack, fragA, noOfFrag)
-                call cmovePtcl3(aTrack, nonIntNucA, noOfNonIntN)
+                call cmovePtcl3(MovedTrack, fragA, noOfFrag)
+                call cmovePtcl3(MovedTrack, nonIntNucA, noOfNonIntN)
              else
-                aTrack.vec = IncidentCopy.vec
-                call cmovePtcl1(aTrack, fragA, noOfFrag)
-                call cmovePtcl1(aTrack, nonIntNucA, noOfNonIntN)
+                MovedTrack.vec = IncidentCopy.vec
+                call cmovePtcl1(MovedTrack, fragA, noOfFrag)
+                call cmovePtcl1(MovedTrack, nonIntNucA, noOfNonIntN)
              endif
           endif
       elseif(never .eq. 3) then
