@@ -4,20 +4,25 @@ c  *     This is intended to open a file that exists already
 c  *     for formatted mode. If it doen not
 c  *     exist or cannot be opened, return cond =1 
 c  ***********************************************************
-         subroutine copenf(io, fn, icon)
+         subroutine copenf(io, fnin, icon)
 c      
 c           io: integer. input.  Fortran logical device number
-c           fn: character(*). input. Disk file name to be openend.
+c           fnin: character(*). input. Disk file name to be openend.
+c                     if it starts with %_, % is replaced by
+c                     hostname. If %_#_, # is also replaced by
+c                     the cumulative event # .
+c                     The same is true  for the name after /.
 c         icon: integer. output. 0--> ok
 c                                1--> cannot be opened.
          implicit none
 #include "Zreadonly.h"
 
-         character*(*) fn
+         character*(*) fnin
          logical opn, ex
          integer io, ios, icon, klena
          character*300 msg
-
+         character*100 fn
+         call cgetfname(fnin, fn)
 c                  see if already opened.
              inquire(file=fn(1:klena(fn)), opened=opn, exist=ex)
              if(opn) then
@@ -56,19 +61,21 @@ c  *     This is intended to open a file
 c  *     for formatted i/o mode. If it
 c  *     cannot be opened, return cond =1 
 c  ***********************************************************
-         subroutine copenfw(io, fn, icon)
+         subroutine copenfw(io, fnin, icon)
 c      
 c           io: integer. input.  Fortran logical device number
-c           fn: character(*). input. Disk file name to be openend.
+c           fnin: character(*). input. Disk file name to be openend.
 c         icon: integer. output. 0--> ok
 c                                1--> cannot be opened.
          implicit none
 #include "Zreadonly.h"
 
-         character*(*) fn
+         character*(*) fnin
          logical opn, ex
          integer io, ios, icon, klena
-         character*100 msg
+         character*100 msg, fn
+
+         call cgetfname(fnin, fn)
 
 c                  see if already opened.
              inquire(file=fn(1:klena(fn)), opened=opn, exist=ex)
@@ -184,3 +191,82 @@ c          skip to the end of previous write
        enddo
  100      continue
        end
+
+      subroutine cgetfname(fnin,  fn)
+      implicit none
+
+      character*(*) fnin  ! input. If it has %_ at the top or
+                          ! if it has /%_ somewhere, 
+                          ! all % will be replaced by hostname
+                          ! If it is  %_#_ at top or it has /%_#_
+                          ! somewhere, all of # will be replaced by
+                          ! the current cumulative event number.
+      character*(*) fn    ! output. 
+
+
+      integer j, klena, nl
+
+      fn = ' '
+      fn = fnin
+      nl = klena(fn)
+      j = 1
+      if( fn(1:2) .eq. '%_') then
+         call creplst( fn, 1 )
+      endif
+      do while( index(fn, '/%_') .gt. 0)
+         j = index(fn, '/%_') + 1
+         call creplst( fn, j)
+      enddo
+      end
+      subroutine creplst( fn, j )
+      implicit none
+      character*(*) fn   ! input.  must be < 256
+      integer j          ! input.  fn(j:j+1) has  '%_'
+
+      integer num, cumnum, klena, leng, leng2
+      character*10  cnum
+      character*64 host   !  sometimes, the complete name may be obtained
+                          !  so it must be long. 
+
+      character*256  fnt
+
+      fnt= ' '
+      fnt = fn(j:klena(fn))
+      if( fnt(1:2) .eq. '%_'  .and. 
+     *       fnt(3:4) .eq. '#_' ) then 
+         call cgetHost(leng, host)
+         call cqEventNo(num,  cumnum)
+         cnum = ' '
+         write(cnum, *) cumnum
+         call kseblk(cnum, '{', leng2)
+         fnt = 
+     *        host(1:leng)//'_'//cnum(1:leng2)//
+     *        '_'//fn(j+4:klena(fn))
+      elseif(fnt(1:2) .eq. '%_') then
+         call cgetHost(leng, host)
+         fnt = host(1:leng)//fn(j+1:klena(fn))
+      endif
+      if(j .gt. 1) then
+         fn = fn(1:j-1)//fnt
+      else
+         fn = fnt
+      endif
+      end
+c      **************
+      subroutine cgetHost(leng, hostn)
+      integer  leng       ! output
+      character*(*) hostn ! output
+
+      character*1 NULL
+      integer  kgetenv
+
+      NULL = char(0)
+      leng = kgetenv("HOSTNAME"//NULL, hostn)
+      if(leng .eq. 0) then
+         leng = kgetenv("HOST"//NULL, hostn)
+         if(leng .eq. 0) then
+            call
+     *      cerrorMsg('Env. var. HOST or HOSTNAME not found',0)
+         endif
+      endif
+      end
