@@ -9,7 +9,7 @@ c
 #include  "Zincidentp.h"
 
       record /coord/ dir
-      character*40 msg
+      character*50 msg
       
       if(Za1ry .eq. 'is') then
          call csPrimIsoAng(dir)
@@ -24,7 +24,9 @@ c                around point source
          call cerrorMsg(msg, 0)
       endif
       end
-#ifdef NEXT486
+#if defined NEXT486
+#define IMAG_P dimag
+#elif defined PCLinux
 #define IMAG_P dimag
 #else
 #define IMAG_P imag
@@ -74,6 +76,8 @@ c
 c             for source SourceDec at hour h, get horizontal vector
           call kdhtoh(SourceDec, h, w1, w2, w3)
           w3 = - w3     ! note  vector def. is opposit
+          w2 = - w2
+          w1 = - w1
 c             convert to detector system
           call khtad(w1, w2, w3, dir.r(1), dir.r(2), dir.r(3))
           dir.sys = 'det'
@@ -105,6 +109,8 @@ c            sample angle in horizontal system
           endif
           call kdhtoh(decx, h, w1, w2, w3)
           w3 = - w3   ! note vector direction is opposit.
+          w2 = - w2
+          w1 = - w1
           call khtad(w1, w2, w3, dir.r(1), dir.r(2), dir.r(3))
           dir.sys = 'det'
       end
@@ -121,7 +127,7 @@ c       ------------------------- init for sampling 1ry angle
      *        wh1, wh2, wh3, w3max
       integer icon, jcon
       external cblkIncident
-      character*120  msg
+      character*200  msg
 c
 c               used if arround point source
            smx=pi/2 -(SourceDec+Ddelta)*Torad
